#include "orbsvcs/Event/EC_Scheduling_Strategy.h"
#include "orbsvcs/Event/EC_QOS_Info.h"



TAO_BEGIN_VERSIONED_NAMESPACE_DECL

TAO_EC_Scheduling_Strategy::~TAO_EC_Scheduling_Strategy ()
{
}

TAO_END_VERSIONED_NAMESPACE_DECL
